@@ -5,7 +5,7 @@ from PythonPals import questions
 import pygame
 import pygame.gfxdraw
 import textwrap
-from player import Player, Coffee, Ruby, Eye
+from PythonPals import player
 
 class Screen():
     def __init__(self, width, height):
